@@ -47,7 +47,8 @@ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSI
 
 #endif
 
-#define SAMPLES_PER_BLOCK 16384
+#define SAMPLES_PER_BLOCK 8192
+#define BYTES_PER_BLOCK 16384
 #define MAX_SWEEP_RANGES 10
 
 enum hackrf_error {
@@ -63,6 +64,7 @@ enum hackrf_error {
 	HACKRF_ERROR_STREAMING_STOPPED = -1003,
 	HACKRF_ERROR_STREAMING_EXIT_CALLED = -1004,
 	HACKRF_ERROR_USB_API_VERSION = -1005,
+	HACKRF_ERROR_NOT_LAST_DEVICE = -2000,
 	HACKRF_ERROR_OTHER = -9999,
 };
 
@@ -175,6 +177,8 @@ extern ADDAPI int ADDCALL hackrf_rffc5071_write(hackrf_device* device, uint8_t r
 extern ADDAPI int ADDCALL hackrf_spiflash_erase(hackrf_device* device);
 extern ADDAPI int ADDCALL hackrf_spiflash_write(hackrf_device* device, const uint32_t address, const uint16_t length, unsigned char* const data);
 extern ADDAPI int ADDCALL hackrf_spiflash_read(hackrf_device* device, const uint32_t address, const uint16_t length, unsigned char* data);
+extern ADDAPI int ADDCALL hackrf_spiflash_status(hackrf_device* device, uint8_t* data);
+extern ADDAPI int ADDCALL hackrf_spiflash_clear_status(hackrf_device* device);
 
 /* device will need to be reset after hackrf_cpld_write */
 extern ADDAPI int ADDCALL hackrf_cpld_write(hackrf_device* device,
@@ -189,8 +193,7 @@ extern ADDAPI int ADDCALL hackrf_set_freq_explicit(hackrf_device* device,
 		const uint64_t if_freq_hz, const uint64_t lo_freq_hz,
 		const enum rf_path_filter path);
 
-/* currently 8-20Mhz - either as a fraction, i.e. freq 20000000hz divider 2 -> 10Mhz or as plain old 10000000hz (double)
-	preferred rates are 8, 10, 12.5, 16, 20Mhz due to less jitter */
+/* 2-20Mhz - either as a fraction, i.e. freq 20000000hz divider 2 -> 10Mhz or as plain old 10000000hz (double) */
 extern ADDAPI int ADDCALL hackrf_set_sample_rate_manual(hackrf_device* device, const uint32_t freq_hz, const uint32_t divider);
 extern ADDAPI int ADDCALL hackrf_set_sample_rate(hackrf_device* device, const double freq_hz);
 
@@ -229,7 +232,7 @@ extern ADDAPI int ADDCALL hackrf_set_hw_sync_mode(hackrf_device* device, const u
 /* Start sweep mode */
 extern ADDAPI int ADDCALL hackrf_init_sweep(hackrf_device* device,
 		const uint16_t* frequency_list, const int num_ranges,
-		const uint32_t num_samples, const uint32_t step_width,
+		const uint32_t num_bytes, const uint32_t step_width,
 		const uint32_t offset, const enum sweep_style style);
 
 /* Operacake functions */
@@ -241,6 +244,23 @@ extern ADDAPI int ADDCALL hackrf_set_operacake_ports(hackrf_device* device,
 
 extern ADDAPI int ADDCALL hackrf_reset(hackrf_device* device);
 
+extern ADDAPI int ADDCALL hackrf_set_operacake_ranges(hackrf_device* device,
+                                                      uint8_t* ranges,
+                                                      uint8_t num_ranges);
+
+extern ADDAPI int ADDCALL hackrf_set_clkout_enable(hackrf_device* device, const uint8_t value);
+
+extern ADDAPI int ADDCALL hackrf_operacake_gpio_test(hackrf_device* device,
+                                                     uint8_t address,
+													 uint16_t* test_result);
+#ifdef HACKRF_ISSUE_609_IS_FIXED
+extern ADDAPI int ADDCALL hackrf_cpld_checksum(hackrf_device* device,
+											   uint32_t* crc);
+#endif /* HACKRF_ISSUE_609_IS_FIXED */
+
+extern ADDAPI int ADDCALL hackrf_set_ui_enable(hackrf_device* device, const uint8_t value);
+extern ADDAPI int ADDCALL hackrf_start_rx_sweep(hackrf_device* device, hackrf_sample_block_cb_fn callback, void* rx_ctx);
+
 #ifdef __cplusplus
 } // __cplusplus defined.
 #endif
